<!--
Copyright (C) 2024 Maxwell G <maxwell@gtmx.me>
SPDX-License-Identifier: MIT
-->

# go-vendor-tools

[![CI Badge](https://gitlab.com/gotmax23/go-vendor-tools/badges/main/pipeline.svg)](https://gitlab.com/gotmax23/go-vendor-tools/-/commits/main)

[![Copr build status][copr-badge]][copr-package] (`@go-sig/go-vendor-tools-dev`)

**This project is currently under active development on the
[`gotmax-2025`](https://gitlab.com/fedora/sigs/go/go-vendor-tools/-/tree/gotmax-2025?ref_type=heads)
branch and is undergoing major cleanup. Please coordinate with @gotmax23 if
you'd like to contribute a non-trivial fix.**

Tools for handling Go library vendoring in Fedora

## Documentation

<https://fedora.gitlab.io/sigs/go/go-vendor-tools/>

## Stability

go-vendor-tools is under active development and available in the stable Fedora
for testing purposes.
Expect some breaking changes between releases.
Anyone using the `%go_vendor_*` macros in active Fedora packages MUST join the
Fedora Golang Matrix room and Fedora Go SIG mailing list to be notified of any
major changes.

## Author

go-vendor-tools was authored by Maxwell G and is maintained by them and the
Fedora Go SIG.

[copr-badge]: https://copr.fedorainfracloud.org/coprs/g/go-sig/go-vendor-tools-dev/package/go-vendor-tools/status_image/last_build.png
[copr-package]: https://copr.fedorainfracloud.org/coprs/g/go-sig/go-vendor-tools-dev/package/go-vendor-tools/
